@@ -1,9 +1,9 @@
-{-# LANGUAGE BangPatterns #-}
-{-# LANGUAGE CPP #-}
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE PackageImports #-}
-{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE BangPatterns         #-}
+{-# LANGUAGE CPP                  #-}
+{-# LANGUAGE DeriveDataTypeable   #-}
+{-# LANGUAGE OverloadedStrings    #-}
+{-# LANGUAGE PackageImports       #-}
+{-# LANGUAGE ScopedTypeVariables  #-}
 {-# LANGUAGE TypeSynonymInstances #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
@@ -127,7 +127,11 @@ import           Data.Typeable
 import           Foreign hiding (peek)
 import           Foreign.C.Types
 import           GHC.ForeignPtr
+#if MIN_VERSION_base(4,6,0)
+import           Prelude hiding (drop, head, take)
+#else
 import           Prelude hiding (catch, drop, head, take)
+#endif
 import           System.IO
 
 #ifndef PORTABLE
