@@ -31,6 +31,7 @@ import           Test.HUnit hiding (Test, path)
 ------------------------------------------------------------------------------
 import           Snap.Internal.Http.Types
 import           Snap.Internal.Debug
+import           Snap.Internal.Exceptions
 import           Snap.Internal.Iteratee.Debug
 import           Snap.Internal.Types
 import           Snap.Iteratee hiding (map)
@@ -78,8 +79,10 @@ testSuccess1 = testCase "fileUploads/success1" $
     hndl' xs = do
         fileMap <- foldM f Map.empty xs
 
-        p1 <- getParam "field1"
-        p2 <- getParam "field2"
+        p1  <- getParam "field1"
+        p1P <- getPostParam "field1"
+        p1Q <- getQueryParam "field1"
+        p2  <- getParam "field2"
 
         liftIO $ do
             assertEqual "file1 contents"
@@ -94,9 +97,9 @@ testSuccess1 = testCase "fileUploads/success1" $
                         (Just formContents1)
                         p1
 
-            assertEqual "field2 contents"
-                        (Just formContents2)
-                        p2
+            assertEqual "field1 POST contents" (Just formContents1) p1P
+            assertEqual "field1 query contents" Nothing p1Q
+            assertEqual "field2 contents" (Just formContents2) p2
 
 
 
@@ -330,7 +333,7 @@ testDisconnectionCleanup = testCase "fileUploads/disconnectionCleanup" $ do
         dirs <- liftM (filter (\x -> x /= "." && x /= "..")) $
                 getDirectoryContents tmpdir
         assertEqual "files should be cleaned up" [] dirs
-    
+
 
     tmpdir = "tempdirC"
     hndl = handleFileUploads tmpdir
@@ -339,7 +342,7 @@ testDisconnectionCleanup = testCase "fileUploads/disconnectionCleanup" $ do
                              hndl'
 
     hndl' _ = return ()
-        
+
 
 ------------------------------------------------------------------------------
 harness :: FilePath -> Snap a -> ByteString -> IO ()
@@ -369,8 +372,8 @@ mkRequest body = do
                 ]
 
     return $ Request "foo" 80 "foo" 999 "foo" 1000 "foo" False hdrs
-                     enum Nothing POST (1,1) [] "" "/" "/"
-                     "/" "" Map.empty
+                     enum Nothing POST (1,1) [] "/" "/"
+                     "/" "" Map.empty Map.empty Map.empty
 
 
 ------------------------------------------------------------------------------
@@ -384,8 +387,8 @@ mkDamagedRequest body = do
                 ]
 
     return $ Request "foo" 80 "foo" 999 "foo" 1000 "foo" False hdrs
-                     enum Nothing POST (1,1) [] "" "/" "/"
-                     "/" "" Map.empty
+                     enum Nothing POST (1,1) [] "/" "/"
+                     "/" "" Map.empty Map.empty Map.empty
   where
     enum = enumBS (S.take (S.length body - 1) body) >==> dieNow
     dieNow _ = throw TestException
@@ -413,6 +416,7 @@ goWrongContentType m s = do
     let rq' = setHeader "Content-Type" "text/plain" rq
     liftM snd (run_ $ runIt m rq')
 
+
 ------------------------------------------------------------------------------
 goSlowEnumerator :: Snap a -> ByteString -> IO Response
 goSlowEnumerator m s = do
@@ -440,6 +444,7 @@ goSlowEnumerator m s = do
 waitabit :: IO ()
 waitabit = threadDelay $ 2*seconds
 
+
 ------------------------------------------------------------------------------
 seconds :: Int
 seconds = (10::Int) ^ (6::Int)
@@ -447,7 +452,7 @@ seconds = (10::Int) ^ (6::Int)
 
 ------------------------------------------------------------------------------
 runIt :: Snap a -> Request -> Iteratee ByteString IO (Request, Response)
-runIt m rq = iterateeDebugWrapper "test" $ runSnap m d d rq
+runIt m rq = iterateeDebugWrapper "test" $ runSnap m d (const $ return ()) rq
   where
     d :: forall a . Show a => a -> IO ()
     d = \x -> show x `deepseq` return ()
